.. _bibliography:

Bibliography
==============

.. _KMS17:

Istvan Kiss, Joel Miller, and Peter Simon. `Mathematics of
epidemics on networks <http://dx.doi.org/10.1007/978-3-319-50806-1>`_.
Springer series on Interdisciplinary Applied Mathematics
**46**. ISBN 978-3-319-50804-7. 2017.

.. _M09:

Joel Miller. `Percolation and epidemics in random clustered networks
<https://doi.org/10.1103/PhysRevE.80.020901>`_.
Physical Review E **80**. August 2009.

.. _MHP11:

Sergey Melnik, Adam Hackett, Mason Porter, Peter Mucha, and James Gleeson.
`The unreasonable effectiveness of tree-based theory for networks with
clustering <https://doi.org/10.1103/PhysRevE.83.036112>`_.
Physical Review E **83**. March 2011.

.. _MR96:

Michael Molloy and Bruce Reed. `A critical point for random graphs
with a given degree sequence <https://doi.org/10.1002/rsa.3240060204>`_.
Random Structures and Algorithms **6** (2--3). March--May 1996.

.. _New02:

M.E.J. Newman. `Spread of epidemic disease on networks
<http://dx.doi.org/10.1103/PhysRevE.66.016128>`_. Physical Review E
**66**. July 2002.

.. _NSW01:

M.E.J. Newman, Steven Strogatz, and Duncan Watts. `Random graphs with
arbitrary degree distributions and their applications
<https://doi.org/10.1103/PhysRevE.64.026118>`_. Physical Review E
**64**. 2001.

.. _NZ00:

M.E.J. Newman and R.M. Ziff. `Efficient Monte Carlo algorithm and high-precision results
for percolation <https://doi.org/10.1103/PhysRevLett.85.4104>`_. Physical Review Letters **85**.
November 2000.

.. _Wil94:

Herbert Wilf. `generatingfunctionology
<https://www2.math.upenn.edu/~wilf/gfology2.pdf>`_. Academic Press. 1994.

.. _Burgio21:

Giulio Burgio, Alex Arenas, Sergio Gómez and Joan T. Matamalas: 
       `Network clique cover approximation to analyze complex contagions through group 
       interactions <https://www.nature.com/articles/s42005-021-00618-z>`_, 
       Comms. Phys. (2021) in press (arXiv:2101.03618)